/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.http;


import javax.xml.bind.DatatypeConverter;
import java.util.HashMap;
import java.util.Map;

/**
 * @author Patrik Bergström
 */
public class HttpRequest {

    private String queryString;
    private String body;
    private Map<String,String> headers = new HashMap<String, String>();

    public void setQueryByString(String queryString) {
        this.queryString = queryString;
    }

    public void setQueryByMap(Map<String, String> queryMap) {
        StringBuilder sb = mapToQuery(queryMap);
        this.queryString = sb.toString();
    }

    public String getQueryString() {
        return queryString;
    }

    public String getBody() {
        return body;
    }

    public void setBody(String body) {
        this.body = body;
    }

    public void addBasicAuthentication(String userName, String password) {
        String base64Part = DatatypeConverter.printBase64Binary((userName + ":" + password).getBytes());
        headers.put("Authorization", "Basic " + base64Part);
    }

    public Map<String, String> getHeaders() {
        return headers;
    }

    public static StringBuilder mapToQuery(Map<String, String> parameters) {
        StringBuilder sb = new StringBuilder();
        int count = 0;
        for (Map.Entry<String, String> key : parameters.entrySet()) {
            sb.append(key.getKey() + "=" + key.getValue());
            count++;
            if (count < parameters.size()) {
                sb.append("&"); //we will have at least one more parameter to add to our query
            }
        }
        return sb;
    }
}
